<?xml version="1.0" encoding="utf-8"?>

<!-- Style sheet to amend org-mode HTML output -->
<!-- Caveat: the source .org file must have had  #+HTML_DOCTYPE: xhtml5  -->

<!-- This software is Open Source. Use it under the GNU Public License. Please do read file Copying.txt -->
<!-- Author and copyright 2023 Dr. Thomas Redelberger, redetho@gmx.de -->

<!--
$Id$
-->

<!-- the xmlns:my... just below must match the namespace decl. in the html element of the input file -->

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:my="http://www.w3.org/1999/xhtml">
    <xsl:output method="xml" indent="yes" encoding="UTF-8" omit-xml-declaration="yes"/>


	<!-- match the root element -->
	<xsl:template match="/">
		<!-- Do DOCTYPE the hard way -->
		<xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html&gt;
</xsl:text>
		<xsl:apply-templates select="*"/>
    </xsl:template>


	<!-- trap out all divs -->
    <xsl:template match="my:div">
		<!-- but do copy all of div's child elements -->
		<xsl:apply-templates select="node()"/>
    </xsl:template>


	<!-- trap out the special title h1 heading -->
    <xsl:template match="my:h1[@class='title']"/>


	<!-- trap out auto generated id attributes -->
    <xsl:template match="@id[starts-with(.,'org')]"/>


	<!-- convert SVG object elements to img elements -->
    <xsl:template match="my:object[@type='image/svg+xml']">
		<xsl:element name="img">
			<xsl:attribute name="src">
				<xsl:value-of select="@data"/>
			</xsl:attribute>
			<xsl:copy-of select="@*[name()!='data' and name()!='type']"/>
		</xsl:element>
    </xsl:template>
		


	<!-- To avoid having a namespace attr. in the result <html>
	     element (or elsewhere), below creates /new/ elements and /new/
	     attributes rather than copies. Because copy-namespaces="no" in
	     xsl:copy-of is only available as from XSLT 2.0
	     -->

	<!-- match any element other than root and attributes -->
	<!-- the match on "*" rather than "node()" omits comments -->
    <xsl:template match="*">
		<xsl:element name="{local-name()}">	
			<xsl:apply-templates select="@* | node()"/>
		</xsl:element>
    </xsl:template>


	<!-- match attributes -->
	<xsl:template match="@*">
		<xsl:attribute name="{local-name()}">
			<xsl:value-of select="."/>
		</xsl:attribute>
    </xsl:template>

</xsl:stylesheet>
